Package: gamma
Title: Dose Rate Estimation from in-Situ Gamma-Ray Spectrometry
        Measurements
Version: 1.1.0
Authors@R: c(
    person("Nicolas", "Frerebeau", , "nicolas.frerebeau@u-bordeaux-montaigne.fr", role = "aut",
           comment = c(ORCID = "0000-0001-5759-4944")),
    person("Brice", "Lebrun", , "brice.lebrun@u-bordeaux-montaigne.fr", role = "aut",
           comment = c(ORCID = "0000-0001-7503-8685")),
    person("Guilhem", "Paradol", , "guilhem.paradol@cea.fr", role = "aut",
           comment = c(ORCID = "0000-0002-8561-4903")),
    person("Magali", "Rizza", , "rizza@cerege.fr", role = "ctb",
           comment = c(ORCID = "0000-0003-2364-5621")),
    person("Christelle", "Lahaye", , "christelle.lahaye@u-bordeaux-montaigne.fr", role = "ctb",
           comment = c(ORCID = "0000-0003-2215-9015")),
    person("Sebastian", "Kreutzer", , "sebastian.kreutzer@uni-heidelberg.de", role = "aut",
           comment = c(ORCID = "0000-0002-0734-2199")),
    person("Archéosciences Bordeaux", , , "services-archeosciences@u-bordeaux-montaigne.fr", role = "cre"),
    person("Université Bordeaux Montaigne", role = c("cph", "fnd")),
    person("CNRS", role = "fnd"),
    person("LabEx Sciences archéologiques de Bordeaux", role = "fnd"),
    person("Idex Aix-Marseille", role = "fnd")
  )
Maintainer: Archéosciences Bordeaux <services-archeosciences@u-bordeaux-montaigne.fr>
Description: Process in-situ Gamma-Ray Spectrometry for Luminescence
    Dating. This package allows to import, inspect and correct the energy
    shifts of gamma-ray spectra. It provides methods for estimating the
    gamma dose rate by the use of a calibration curve as described in
    Mercier and Falguères (2007). The package only supports Canberra CNF
    and TKA and Kromek SPE files.
License: GPL-3
URL: https://crp2a.github.io/gamma/, https://github.com/crp2a/gamma
BugReports: https://github.com/crp2a/gamma/issues
Depends: R (>= 3.5)
Imports: ggplot2, graphics, IsoplotR, methods, rlang, rxylib, stats,
        tools, utils
Suggests: covr, knitr, rmarkdown, testthat (>= 3.0.0), vdiffr (>=
        1.0.0)
VignetteBuilder: knitr
Config/testthat/edition: 3
Encoding: UTF-8
LazyData: false
RoxygenNote: 7.3.2
Collate: 'AllClasses.R' 'AllGenerics.R' 'baseline.R'
        'baseline_linear.R' 'baseline_rubberband.R' 'baseline_snip.R'
        'coerce.R' 'data.R' 'dose_fit.R' 'dose_predict.R'
        'energy_calibrate.R' 'gamma-package.R' 'initialize.R'
        'mutators.R' 'operators.R' 'peaks_find.R' 'peaks_search.R'
        'plot.R' 'read.R' 'show.R' 'signal_integrate.R'
        'signal_slice.R' 'signal_split.R' 'signal_stabilize.R'
        'smooth.R' 'smooth_rectangular.R' 'smooth_savitzky.R'
        'smooth_triangular.R' 'subset.R' 'summarize.R' 'utilities.R'
        'validate.R' 'zzz.R'
NeedsCompilation: no
Packaged: 2024-09-23 19:26:18 UTC; nicolas
Author: Nicolas Frerebeau [aut] (<https://orcid.org/0000-0001-5759-4944>),
  Brice Lebrun [aut] (<https://orcid.org/0000-0001-7503-8685>),
  Guilhem Paradol [aut] (<https://orcid.org/0000-0002-8561-4903>),
  Magali Rizza [ctb] (<https://orcid.org/0000-0003-2364-5621>),
  Christelle Lahaye [ctb] (<https://orcid.org/0000-0003-2215-9015>),
  Sebastian Kreutzer [aut] (<https://orcid.org/0000-0002-0734-2199>),
  Archéosciences Bordeaux [cre],
  Université Bordeaux Montaigne [cph, fnd],
  CNRS [fnd],
  LabEx Sciences archéologiques de Bordeaux [fnd],
  Idex Aix-Marseille [fnd]
Repository: CRAN
Date/Publication: 2024-09-23 22:00:12 UTC
Built: R 4.6.0; ; 2026-04-28 03:46:36 UTC; unix
