# Generated by roxygen2: do not edit by hand

S3method(as.data.frame,GammaSpectrum)
S3method(as.data.frame,PeakPosition)
S3method(as.list,PeakPosition)
S3method(as.matrix,GammaSpectrum)
S3method(as.matrix,PeakPosition)
exportMethods("[")
exportMethods("[[")
exportMethods("set_energy<-")
exportMethods("set_energy_calibration<-")
exportMethods("set_method<-")
exportMethods("set_names<-")
exportMethods(Arith)
exportMethods(Compare)
exportMethods(Logic)
exportMethods(Math)
exportMethods(Math2)
exportMethods(Summary)
exportMethods(baseline_linear)
exportMethods(baseline_rubberband)
exportMethods(baseline_snip)
exportMethods(dose_fit)
exportMethods(dose_predict)
exportMethods(energy_calibrate)
exportMethods(get_channels)
exportMethods(get_counts)
exportMethods(get_energy)
exportMethods(get_energy_calibration)
exportMethods(get_hash)
exportMethods(get_livetime)
exportMethods(get_method)
exportMethods(get_names)
exportMethods(get_rates)
exportMethods(get_realtime)
exportMethods(get_residuals)
exportMethods(has_calibration)
exportMethods(has_energy)
exportMethods(length)
exportMethods(peaks_find)
exportMethods(peaks_search)
exportMethods(plot)
exportMethods(range_channels)
exportMethods(range_energy)
exportMethods(read)
exportMethods(signal_baseline)
exportMethods(signal_correct)
exportMethods(signal_integrate)
exportMethods(signal_slice)
exportMethods(signal_smooth)
exportMethods(signal_split)
exportMethods(signal_stabilize)
exportMethods(smooth_rectangular)
exportMethods(smooth_savitzky)
exportMethods(smooth_triangular)
exportMethods(summarise)
importFrom(IsoplotR,york)
importFrom(ggplot2,aes)
importFrom(ggplot2,coord_cartesian)
importFrom(ggplot2,element_text)
importFrom(ggplot2,facet_wrap)
importFrom(ggplot2,geom_errorbar)
importFrom(ggplot2,geom_errorbarh)
importFrom(ggplot2,geom_path)
importFrom(ggplot2,geom_point)
importFrom(ggplot2,geom_pointrange)
importFrom(ggplot2,geom_segment)
importFrom(ggplot2,geom_vline)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,ggsave)
importFrom(ggplot2,labs)
importFrom(ggplot2,scale_x_continuous)
importFrom(ggplot2,sec_axis)
importFrom(ggplot2,theme)
importFrom(ggplot2,theme_bw)
importFrom(ggplot2,vars)
importFrom(ggplot2,waiver)
importFrom(graphics,plot)
importFrom(methods,"as<-")
importFrom(methods,"slot<-")
importFrom(methods,Arith)
importFrom(methods,Compare)
importFrom(methods,Logic)
importFrom(methods,Math)
importFrom(methods,Math2)
importFrom(methods,Summary)
importFrom(methods,as)
importFrom(methods,callGeneric)
importFrom(methods,new)
importFrom(methods,setClass)
importFrom(methods,setClassUnion)
importFrom(methods,setGeneric)
importFrom(methods,setMethod)
importFrom(methods,slot)
importFrom(rlang,.data)
importFrom(tools,file_ext)
importFrom(tools,file_path_sans_ext)
importFrom(tools,list_files_with_exts)
importFrom(tools,md5sum)
